==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/app/translations/qmmp_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nie czyść listy</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Zacznij odtwarzać bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Wstrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Wstrzymaj jeśli odtwarza, odtwarzaj w przeciwnym wypadku</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Zatrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Wyświetl okno dialogowe Skocz do</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Ustaw głośność odtwarzania (np: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Wyświetl poziom głośności</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Wyłącz/Włącz dźwięk</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Wyświetl stan wyciszenia</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Przeskocz do przodu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Przeskocz do tyłu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Pokaż/ukryj aplikację</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Pokaż okno główne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Wyświetl okno dialogowe dodawania plików</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Wyświetl okno dialogowe dodawania katalogów</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>Nieznane polecenie</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Użycie: qmmp [opcje] [pliki]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Uruchom qmmp z określonym interfejsem użytkownika</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="415"/>
        <source>List all available user interfaces</source>
        <translation>Wyświetl wszystkie dostępne interfejsy użytkownika</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="416"/>
        <source>Don&apos;t start the application</source>
        <translation>Nie uruchamiaj aplikacji</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="417"/>
        <source>Display this text and exit</source>
        <translation>Wyświetla ten tekst i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="418"/>
        <source>Print version number and exit</source>
        <translation>Wyświetla wersję programu i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Home page: %1</source>
        <translation>Strona główna: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>Development page: %1</source>
        <translation>Strona rozwoju: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Bug tracker: %1</source>
        <translation>Bugtracker: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Command Line Help</source>
        <translation>Pomoc linii poleceń</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="440"/>
        <source>QMMP version: %1</source>
        <translation>Wersja QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="441"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Skompilowane z wersją Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Using Qt version: %1</source>
        <translation>Używana wersja Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Qmmp Version</source>
        <translation>Wersja Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="462"/>
        <source>User Interfaces</source>
        <translation>Interfejs użytkownika</translation>
    </message>
</context>
</TS>

==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/app/translations/qmmp_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nie czyść listy</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Zacznij odtwarzać bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Wstrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Wstrzymaj jeśli odtwarza, odtwarzaj w przeciwnym wypadku</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Zatrzymaj bieżący utwór</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Wyświetl okno dialogowe Skocz do</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Ustaw głośność odtwarzania (np: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>Wyłącz/Włącz dźwięk</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Przeskocz do przodu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Przeskocz do tyłu na liście odtwarzania</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Pokaż/ukryj aplikację</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Pokaż okno główne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Wyświetl okno dialogowe dodawania plików</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Wyświetl okno dialogowe dodawania katalogów</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="94"/>
        <source>Unknown command</source>
        <translation>Nieznane polecenie</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="330"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Użycie: qmmp [opcje] [pliki]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="331"/>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="335"/>
        <source>Don&apos;t start the application</source>
        <translation>Nie uruchamiaj aplikacji</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="336"/>
        <source>Display this text and exit</source>
        <translation>Wyświetla ten tekst i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="337"/>
        <source>Print version number and exit</source>
        <translation>Wyświetla wersję programu i wychodzi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="338"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Pomysły, poprawki, raporty o błędach proszę wysyłać na forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Command Line Help</source>
        <translation>Linia Poleceń Pomoc</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="354"/>
        <source>QMMP version: %1</source>
        <translation>Wersja QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="355"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Skompilowane z wersją QT: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="356"/>
        <source>Using Qt version: %1</source>
        <translation>Używana wersja Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="359"/>
        <source>Qmmp Version</source>
        <translation>Wersja Qmmp</translation>
    </message>
</context>
</TS>
